Project Showcase
================
This page lists some awesome projects built with kani!

Made a project of your own you'd like to show off? Make a PR and add it to this list!

* `Calypso: A Dungeon Master's Assistant <https://github.com/northern-lights-province/calypso>`_ (by @zhudotexe)
